@@ -310,6 +310,11 @@ typedef struct {
 /* Internal version of a pmResult */
 typedef struct __pmResult {
     __pmTimestamp	timestamp;	/* time stamped by collector */
+#ifdef PM_PAD_RESULT
+    __int32_t		pad;		/* move numpmid down a bit so numpmid */
+    					/* offset is >= offset for pmResult */
+					/* and pmHighResResult */
+#endif
     int                 numpmid;	/* number of PMIDs */
     pmValueSet		*vset[1];	/* set of value sets, one per PMID */
 } __pmResult;
@@ -814,6 +819,7 @@ typedef struct {
     int		numti;		/* (when reading) no. temporal index entries */
     __pmLogTI	*ti;		/* (when reading) temporal index */
     struct __pmnsTree *pmns;	/* namespace from meta data */
+    int		numpmid;	/* no. names in namespace */
     int		multi;		/* part of a multi-archive context */
 } __pmLogCtl;
 
@@ -854,8 +860,9 @@ typedef struct {
     int			ac_cache_idx;	/* used in interp.c */
     /*
      * These were added to the ABI in order to support multiple archives
-     * in a single context.
+     * in a single context (for archive reading, not writing)
      */
+    int			ac_meta_loaded;	/* metadata has been loaded */
     int			ac_mark_done;	/* mark record between archives */
 					/*   has been generated */
     int			ac_num_logs;	/* The number of archives */
@@ -1002,6 +1009,8 @@ PCP_CALL extern int __pmStuffValue(const pmAtomValue *, pmValue *, int);
 /* Archive context helper. */
 PCP_CALL extern int __pmFindOrOpenArchive(__pmContext *, const char *, int);
 PCP_CALL extern int __pmLogFindOpen(__pmArchCtl *, const char *);
+PCP_CALL extern int __pmLogChangeArchive(__pmContext *, int);
+
 
 /* Generic access control routines */
 PCP_CALL extern int __pmAccAddOp(unsigned int);
@@ -1549,6 +1558,13 @@ PCP_CALL extern void __pmPutTimeval(const __pmTimestamp *, __int32_t *);
 /* remove old files from a map directory */
 PCP_CALL extern int __pmCleanMapDir(const char *, const char *);
 
+/* Check for duplicate label sets. */
+PCP_CALL extern void __pmCheckDupLabels(const __pmArchCtl *);
+
+/* diagnostic output throttling */
+PCP_CALL extern int __pmNotifyThrottle(const char *, int);
+PCP_CALL extern int __pmResetNotifyThrottle(const char *, int, int);
+
 #ifdef __cplusplus
 }
 #endif
