@@ -210,6 +210,12 @@ extern int do_events(pmValueSet *);
 /* cleanup control fds and sockets etc prior to reexec or exit */
 extern void cleanup(void);
 
+/* if launched from control-driven scripts */
+extern int runfromcontrol;
+
+/* expand -d directory argument */
+extern int do_dir(char *, char *);
+
 /* QA testing and error injection support ... see do_request() */
 extern int	qa_case;
 #define QA_OFF		100
